@@ -27,6 +27,7 @@
  */
 
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <signal.h>
 #include <fcntl.h>
 #ifndef sun
@@ -1022,7 +1023,7 @@ int x2, y2;
 
   /* Calculate the cost to move the cursor to the right x position */
   costx = EXPENSIVE;
-  if (x1 >= 0)	/* relativ x positioning only if we know where we are */
+  if (x1 >= 0)	/* relative x positioning only if we know where we are */
     {
       if (dx > 0)
 	{
@@ -2308,7 +2309,7 @@ char *str;
 
 
 /*
- *  Refreshes the harstatus of the fore window. Shouldn't be here...
+ *  Refreshes the hardstatus of the fore window. Shouldn't be here...
  */
 void
 RefreshHStatus()
@@ -3772,7 +3773,7 @@ struct event *ev;
 char *data;
 {
   display = (struct display *)data;
-  debug1("disp_status_fn for display %x\n", (int)display);
+  debug1("disp_status_fn for display %lx\n", (long)display);
   if (D_status)
     RemoveStatus();
 }
